@@ -1,5 +1,5 @@
-from asup import Asup
-from tasks import ensure_config_exists
+from asup.app import Asup
+from asup.tasks import ensure_config_exists
 
 
 def asup():
